@@ -5,7 +5,11 @@ wrap_lamindb <- function(py_lamindb) {
   tryCatch(
     {
       instance_settings <- py_lamindb$setup$settings$instance
-      instance_slug <- paste0(instance_settings$owner, "/", instance_settings$name)
+      instance_slug <- paste0(
+        instance_settings$owner,
+        "/",
+        instance_settings$name
+      )
       set_default_instance(instance_slug)
     },
     error = function(err) {
@@ -31,23 +35,27 @@ wrap_lamindb <- function(py_lamindb) {
     tryCatch(
       storage <- reticulate::py_repr(py_lamindb$settings$storage), # nolint object_usage_linter
       error = function(err) {
-        cli::cli_abort(c(
-          paste(
-            "Failed to identify storage for instance {.val {instance_slug}}.",
-            "The directory for this instance may have been deleted."
+        cli::cli_abort(
+          c(
+            paste(
+              "Failed to identify storage for instance {.val {instance_slug}}.",
+              "The directory for this instance may have been deleted."
+            ),
+            "i" = paste(
+              "Restart your R session and use {.code lamin_connect()} to",
+              "connect to another instance"
+            ),
+            "x" = "Error message: {err}"
           ),
-          "i" = paste(
-            "Restart your R session and use {.code lamin_connect()} to",
-            "connect to another instance"
-          ),
-          "x" = "Error message: {err}"
-        ), call = rlang::caller_env(4))
+          call = rlang::caller_env(4)
+        )
       }
     )
   }
 
   reticulate::register_module_help_handler(
-    "lamindb", lamindb_module_help_handler
+    "lamindb",
+    lamindb_module_help_handler
   )
 
   wrap_python(
@@ -98,12 +106,26 @@ lamindb_finish <- function(self, ...) {
     pkgs <- get_loaded_packages()
     pkg_repos <- get_package_repositories(pkgs)
 
-    withr::with_options(list(repos = unique(c(pkg_repos, getOption("repos")))), {
-      pak::lockfile_create(
-        pkg = pkgs,
-        lockfile = file.path(run_dir, "r_pak_lockfile.json")
-      )
-    })
+    tryCatch(
+      withr::with_options(
+        list(repos = unique(c(pkg_repos, getOption("repos")))),
+        {
+          pak::lockfile_create(
+            pkg = pkgs,
+            lockfile = file.path(run_dir, "r_pak_lockfile.json")
+          )
+        }
+      ),
+      error = function(err) {
+        cli::cli_warn(
+          c(
+            "Failed to create the lockfile for the run using pak.",
+            "i" = "Please reach out via GitHub or Slack if you need help.",
+            "x" = "Error message: {err}"
+          )
+        )
+      }
+    )
   }
 
   tryCatch(
