@@ -3,23 +3,20 @@ if (isTRUE(as.logical(Sys.getenv("NOT_CRAN", "false")))) {
   timestamp <- format(Sys.time(), "%Y%m%d%H%M%S")
   test_name <- paste0("laminr-test-", timestamp)
 
-  # Create a new test environment
-  install_lamindb(envname = test_name, extra_packages = "bionty")
   if (Sys.getenv("LAMIN_TEST_VERSION") == "devel") {
-    reticulate::py_install("git+https://github.com/laminlabs/lamindb.git")
+    require_module(
+      "lamindb",
+      options = "bionty",
+      source = "git+https://github.com/laminlabs/lamindb.git"
+    )
+  } else {
+    require_module("lamindb", options = "bionty")
   }
-  reticulate::py_config()
-  withr::defer(
-    {
-      tryCatch(
-        reticulate::virtualenv_remove(test_name, confirm = FALSE),
-        error = function(err) {
-          reticulate::conda_remove(test_name)
-        }
-      )
-    },
-    testthat::teardown_env()
-  )
+
+  # Make sure we are using the ephemeral environment
+  withr::with_envvar(c("RETICULATE_USE_MANAGED_VENV" = "yes"), {
+    reticulate::py_config()
+  })
 
   # Reset the current instance when we are done
   current_instance <- laminr::get_current_lamin_instance()
@@ -37,5 +34,4 @@ if (isTRUE(as.logical(Sys.getenv("NOT_CRAN", "false")))) {
   ln <- import_module("lamindb")
   # Reset the default instance so we can connect to another
   withr::defer(options(LAMINR_DEFAULT_INSTANCE = NULL), testthat::teardown_env())
-
 }
